@@ -107,13 +107,17 @@ package Aniki::Row {
     }
 
     sub can {
-        my ($self, $method) = @_;
-        my $code = $self->SUPER::can($method);
+        my ($invocant, $method) = @_;
+        my $code = $invocant->SUPER::can($method);
         return $code if defined $code;
 
-        my $column = $method;
-        return sub { $self->get($column)   } if exists $self->row_data->{$column};
-        return sub { $self->relay($column) } if $self->relationships && $self->relationships->get_relationship($column);
+        if (ref $invocant) {
+            my $self   = $invocant;
+            my $column = $method;
+            return sub { $self->get($column)   } if exists $self->row_data->{$column};
+            return sub { $self->relay($column) } if $self->relationships && $self->relationships->get_relationship($column);
+        }
+
         return undef; ## no critic
     }
 
